summaryrefslogtreecommitdiffstats
path: root/pym
diff options
context:
space:
mode:
authorZac Medico <zmedico@gentoo.org>2011-05-22 14:20:56 -0700
committerZac Medico <zmedico@gentoo.org>2011-05-22 14:20:56 -0700
commitdd444ef33752aa268a78f425211e74fa2f2706c9 (patch)
tree2b7e65f535b265bce6bba4d44bf62b299f4bcf00 /pym
parentfabc1017c5d1c5273e63f0acf47d9589ff982d2d (diff)
downloadportage-dd444ef33752aa268a78f425211e74fa2f2706c9.tar.gz
portage-dd444ef33752aa268a78f425211e74fa2f2706c9.tar.bz2
portage-dd444ef33752aa268a78f425211e74fa2f2706c9.zip
_validate_blockers: reference bug 128809
Diffstat (limited to 'pym')
-rw-r--r--pym/_emerge/depgraph.py11
1 files changed, 7 insertions, 4 deletions
diff --git a/pym/_emerge/depgraph.py b/pym/_emerge/depgraph.py
index 0bd351278..caf150ac5 100644
--- a/pym/_emerge/depgraph.py
+++ b/pym/_emerge/depgraph.py
@@ -4175,7 +4175,8 @@ class depgraph(object):
"""Remove any blockers from the digraph that do not match any of the
packages within the graph. If necessary, create hard deps to ensure
correct merge order such that mutually blocking packages are never
- installed simultaneously."""
+ installed simultaneously. Also add runtime blockers from all installed
+ packages if any of them haven't been added already (bug 128809)."""
if "--buildpkgonly" in self._frozen_config.myopts or \
"--nodeps" in self._frozen_config.myopts:
@@ -4186,9 +4187,11 @@ class depgraph(object):
if True:
# Pull in blockers from all installed packages that haven't already
# been pulled into the depgraph. This is not enabled by default
# due to the performance penalty that is incurred by all the
# additional dep_check calls that are required.
# For installed packages, always ignore blockers from DEPEND since
# only runtime dependencies should be relevant for packages that
@@ -4186,9 +4187,11 @@ class depgraph(object):
if True:
# Pull in blockers from all installed packages that haven't already
- # been pulled into the depgraph. This is not enabled by default
- # due to the performance penalty that is incurred by all the
- # additional dep_check calls that are required.
+ # been pulled into the depgraph, in order to ensure that the are
+ # respected (bug 128809). Due to the performance penalty that is
+ # incurred by all the additional dep_check calls that are required,
+ # blockers returned from dep_check are cached on disk by the
+ # BlockerCache class.
# For installed packages, always ignore blockers from DEPEND since
# only runtime dependencies should be relevant for packages that